Index: /trunk/BNC/bncgetthread.cpp
===================================================================
--- /trunk/BNC/bncgetthread.cpp	(revision 3304)
+++ /trunk/BNC/bncgetthread.cpp	(revision 3305)
@@ -465,6 +465,6 @@
         }
       
         // Check observations comming twice (e.g. KOUR0 Problem)
         // -----------------------------------------------------
         QMap<QString, long>::const_iterator it = _prnLastEpo.find(prn);
         if (it == _prnLastEpo.end()) {
@@ -480,5 +480,5 @@
           else if (obsTime == oldTime) {
             emit( newMessage(_staID + 
-               ": observation comming more than once " + prn.toAscii(), false));
+               ": observation coming more than once " + prn.toAscii(), false));
             continue;
           }
@@ -465,6 +465,6 @@
         }
       
-        // Check observations comming twice (e.g. KOUR0 Problem)
-        // -----------------------------------------------------
+        // Check observations coming twice (e.g. KOUR0 Problem)
+        // ----------------------------------------------------
         QMap<QString, long>::const_iterator it = _prnLastEpo.find(prn);
         if (it == _prnLastEpo.end()) {
